@@ -37,10 +37,19 @@ def paste(content: str):
     return r.json()
 
 
+def get_stats():
+    res = requests.get(f"{BASE_URL}/gstats").json()
+    chats = res["chats"]
+    pms = res["pm"]
+    return chats, pms
+
+
 kode = get_available_language()
 lang_flags = {
     "en": f"{emoji.FLAG_UNITED_STATES} English",
     "id": f"{emoji.FLAG_INDONESIA} Indonesia",
+    "su": f"{emoji.FLAG_INDONESIA} Sundanese",
+    "jv": f"{emoji.FLAG_INDONESIA} Javanese",
     "jp": f"{emoji.FLAG_JAPAN} Japan",
     "hi": f"{emoji.FLAG_INDIA} India",
     "gj": f"{emoji.FLAG_INDIA} Gujarat",
