@@ -10,7 +10,7 @@ def get_sudos(chat_id: int):
         z: list[int] = r.json()["sudos"]
         return z
     except KeyError:
-        return 404
+        return None
 
 
 def add_sudo(chat_id: int, user_id: int):
